/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NAnt.Core;

namespace TopCoder.Test.Framework
{
    /// <summary>
    /// Defines a custom exception which is thrown when executing the task causes an error in the
    /// <c>ServerAppTestTask</c> class.
    /// </summary>
    /// <remarks>
    /// This class is thread-safe.
    /// </remarks>
    ///
    /// <author>real_vg</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public class ServerTaskException : BuildException
    {
        /// <summary>
        /// Represents the array of inner exceptions. Each element in the array will represent one of the cause
        /// exceptions of this exception.
        /// </summary>
        private Exception[] innerExceptions;

        /// <summary>
        /// Gets the inner exceptions array of this exception.
        /// </summary>
        /// <value>The inner exceptions array of this exception.</value>
        public Exception[] InnerExceptions
        {
            get
            {
                return this.innerExceptions;
            }
        }

        /// <summary>
        /// Creates a new instance of <c>ServerTaskException</c> class. The detailed error message and inner
        /// exceptions array are given.
        /// </summary>
        /// <param name="message">A detailed error message descrbing the nature of the error.</param>
        /// <param name="innerExceptions">The array of inner exceptions. Each element in the array will represent
        /// one of the cause exceptions of this exception.</param>
        public ServerTaskException(string message, Exception[] innerExceptions)
            : base(message, innerExceptions != null ? innerExceptions[0] : null)
        {
            this.innerExceptions = innerExceptions;
        }
    }
}
