/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NAnt.Core.Types;

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// <p>
    /// Defines an abstract base class derived from <c>Server</c> class for all the classes which represent an
    /// application server to be used while running tests.
    /// </p>
    /// <p>
    /// The supported options are:
    /// DEPLOYMENT_DIR - specifies the directory that the application should be deployed to.
    /// </p>
    /// </summary>
    /// <remarks>
    /// This class is not thread-safe since its parent class is mutable.
    /// </remarks>
    ///
    /// <author>real_vg</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public abstract class ApplicationServer : Server
    {
        /// <summary>
        /// Represents the name(key) of the deployment_dir option. The value of the deployment_dir option
        /// represents the directory that the application should be deployed to.
        /// </summary>
        public static readonly string DEPLOYMENT_DIR = "deployment_dir";

        /// <summary>
        /// Gets the value of the deployment_dir option.
        /// </summary>
        /// <value>The value of the deployment_dir option.</value>
        /// <exception cref="ServerException">If the option value is missing or an empty string.</exception>
        public string DeploymentDirectory
        {
            get
            {
                Option option = Options[DEPLOYMENT_DIR];
                if (option == null)
                {
                    throw new ServerException("The option value for deployment_dir is missing.");
                }
                if (option.Value.Trim().Length == 0)
                {
                    throw new ServerException("The option value for deployment_dir is empty.");
                }
                return option.Value;
            }
        }

        /// <summary>
        /// Creates a new instance of <c>ApplicationServer</c> class.
        /// </summary>
        protected ApplicationServer() : base()
        {
        }
    }
}