/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NAnt.Core;
using NAnt.Core.Types;
using NUnit.Framework;
using TopCoder.Test.Framework.Servers.Web;

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// Tests the functionality and error cases of <c>ApplicationServer</c> class.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public abstract class ApplicationServerUnitTest : ServerUnitTest
    {
        /// <summary>
        /// Tests the accuracy of the constructor.
        /// </summary>
        [Test]
        public void TestApplicationServer_Accuracy()
        {
            Assert.IsNotNull(server, "Constructor should be correct.");
        }

        /// <summary>
        /// Tests the <c>DeploymentDirectory</c> Property when the option value is missing,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDeploymentDirectory_MissingOptionValue()
        {
            server.Options = new OptionCollection();
            string deploymentDir = (server as ApplicationServer).DeploymentDirectory;
        }

        /// <summary>
        /// Tests the <c>DeploymentDirectory</c> Property when the option value is invalid,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDeploymentDirectory_InvalidOptionValue()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { ApplicationServer.DEPLOYMENT_DIR }, new string[] { " " });
            server.Options = collection;

            string deploymentDir = (server as ApplicationServer).DeploymentDirectory;
        }

        /// <summary>
        /// Tests the accuracy of <c>DeploymentDirectory</c> Property.
        /// </summary>
        public void TestDeploymentDirectory_GetAccuracy()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { ApplicationServer.DEPLOYMENT_DIR }, new string[] { "deploymentDir" });
            server.Options = collection;

            // check the value
            Assert.AreEqual("deploymentDir", (server as ApplicationServer).DeploymentDirectory,
                "The value of deploymentDir should be got properly.");
        }
    }
}
