/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NAnt.Core;
using NAnt.Core.Types;
using NUnit.Framework;

namespace TopCoder.Test.Framework.Servers
{
    /// <summary>
    /// Tests the functionality and error cases of <c>DatabaseServer</c> class. A mock class will be used for
    /// testing.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>1.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class DatabaseServerUnitTest : ServerUnitTest
    {
        /// <summary>
        /// Initiates <see cref="ServerUnitTest.meType"/>.
        /// </summary>
        public DatabaseServerUnitTest()
        {
            meType = typeof(MockDatabaseServer);
        }

        /// <summary>
        /// Tests the accuracy of the constructor.
        /// </summary>
        [Test]
        public void TestDatabaseServer_Accuracy()
        {
            Assert.IsNotNull(server, "Constructor should be correct.");
        }

        /// <summary>
        /// Tests the <c>DatabaseDriver</c> Property when the option value is missing,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDatabaseDriver_MissingOptionValue()
        {
            server.Options = new OptionCollection();
            string databaseDriver = (server as DatabaseServer).DatabaseDriver;
        }

        /// <summary>
        /// Tests the <c>DatabaseDriver</c> Property when the option value is invalid,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDatabaseDriver_InvalidOptionValue()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.DB_DRIVER }, new string[] { " " });
            server.Options = collection;

            string databaseDriver = (server as DatabaseServer).DatabaseDriver;
        }

        /// <summary>
        /// Tests the accuracy of <c>DatabaseDriver</c> Property.
        /// </summary>
        public void TestDatabaseDriver_GetAccuracy()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.DB_DRIVER }, new string[] { "databaseDriver" });
            server.Options = collection;

            // check the value
            Assert.AreEqual("databaseDriver", (server as DatabaseServer).DatabaseDriver,
                "The value of databaseDriver should be got properly.");
        }

        /// <summary>
        /// Tests the <c>DatabaseConnectionString</c> Property when the option value is missing,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDatabaseConnectionString_MissingOptionValue()
        {
            server.Options = new OptionCollection();
            string databaseConnectionString = (server as DatabaseServer).DatabaseConnectionString;
        }

        /// <summary>
        /// Tests the <c>DatabaseConnectionString</c> Property when the option value is invalid,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestDatabaseConnectionString_InvalidOptionValue()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.DB_CONNECTION_STR }, new string[] { " " });
            server.Options = collection;

            string databaseConnectionString = (server as DatabaseServer).DatabaseConnectionString;
        }

        /// <summary>
        /// Tests the accuracy of <c>DatabaseConnectionString</c> Property.
        /// </summary>
        public void TestDatabaseConnectionString_GetAccuracy()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.DB_CONNECTION_STR }, new string[] { "DatabaseConnectionString" });
            server.Options = collection;

            // check the value
            Assert.AreEqual("DatabaseConnectionString", (server as DatabaseServer).DatabaseConnectionString,
                "The value of databaseConnectionString should be got properly.");
        }

        /// <summary>
        /// Tests the <c>SqlInitScript</c> Property when the option value is missing,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestSqlInitScript_MissingOptionValue()
        {
            server.Options = new OptionCollection();
            string sqlInitScript = (server as DatabaseServer).SqlInitScript;
        }

        /// <summary>
        /// Tests the <c>SqlInitScript</c> Property when the option value is invalid,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestSqlInitScript_InvalidOptionValue()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.SQL_INIT_SCRIPT }, new string[] { " " });
            server.Options = collection;

            string sqlInitScript = (server as DatabaseServer).SqlInitScript;
        }

        /// <summary>
        /// Tests the accuracy of <c>SqlInitScript</c> Property.
        /// </summary>
        public void TestSqlInitScript_GetAccuracy()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.SQL_INIT_SCRIPT }, new string[] { "SqlInitScript" });
            server.Options = collection;

            // check the value
            Assert.AreEqual("SqlInitScript", (server as DatabaseServer).SqlInitScript,
                "The value of sqlInitScript should be got properly.");
        }

        /// <summary>
        /// Tests the <c>SqlCleanUpScript</c> Property when the option value is missing,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestSqlCleanUpScript_MissingOptionValue()
        {
            server.Options = new OptionCollection();
            string sqlCleanUpScript = (server as DatabaseServer).SqlCleanUpScript;
        }

        /// <summary>
        /// Tests the <c>SqlCleanUpScript</c> Property when the option value is invalid,
        /// expect ServerException.
        /// </summary>
        [Test, ExpectedException(typeof(ServerException))]
        public void TestSqlCleanUpScript_InvalidOptionValue()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.SQL_CLEANUP_SCRIPT }, new string[] { " " });
            server.Options = collection;

            string sqlCleanUpScript = (server as DatabaseServer).SqlCleanUpScript;
        }

        /// <summary>
        /// Tests the accuracy of <c>SqlCleanUpScript</c> Property.
        /// </summary>
        public void TestSqlCleanUpScript_GetAccuracy()
        {
            // set the option first
            OptionCollection collection = UnitTestHelper.CreateOptionCollection(
                new string[] { DatabaseServer.SQL_CLEANUP_SCRIPT }, new string[] { "SqlCleanUpScript" });
            server.Options = collection;

            // check the value
            Assert.AreEqual("SqlCleanUpScript", (server as DatabaseServer).SqlCleanUpScript,
                "The value of sqlCleanUpScript should be got properly.");
        }
    }
}
